@@ -1,7 +1,8 @@
 /* BEGIN_COMMON_COPYRIGHT_HEADER
- * (c)LGPL2+
- * Copyright: 2019 Tianjin KYLIN Information Technology Co., Ltd.
- *            2012 Razor team
+ *
+ * Copyright: 2023, KylinSoft Co., Ltd.
+ * Copyright: 2012 Razor team
+ * 
  * Authors:
  *   Christian Surlykke <christian@surlykke.dk>
  *
@@ -52,7 +53,7 @@ public slots:
     bool doAction(Action action);
 
 private:
-    QList<PowerProvider*> mProviders;
+    PowerProvider *m_systemdProvider;
 };
 
 #endif // UKUIPOWER_H
