@@ -1,7 +1,8 @@
 /* BEGIN_COMMON_COPYRIGHT_HEADER
- * (c)LGPL2+
- * Copyright: 2019 Tianjin KYLIN Information Technology Co., Ltd.
- *            2012 Razor team
+ * 
+ * Copyright: 2023, KylinSoft Co., Ltd.
+ * Copyright: 2012 Razor team
+ * 
  * Authors:
  *   Christian Surlykke <christian@surlykke.dk>
  *
@@ -33,8 +34,7 @@ class IdleDBusAdaptor : public QDBusAbstractAdaptor
     Q_CLASSINFO("D-Bus Interface", "org.gnome.SessionManager.Presence")
 
 public:
-    IdleDBusAdaptor(IdleWatcher *mIdleWatch)
-        : QDBusAbstractAdaptor(mIdleWatch)
+    IdleDBusAdaptor(IdleWatcher *mIdleWatch) : QDBusAbstractAdaptor(mIdleWatch)
     {
         connect(mIdleWatch, &IdleWatcher::StatusChanged, this , &IdleDBusAdaptor::StatusChanged);
     }
